#ifndef bvgl_processes_h_
#define bvgl_processes_h_

#include <bprb/bprb_macros.h>
#include <bprb/bprb_func_process.h>

// execute and const functions
DECLARE_FUNC_CONS(bvgl_generate_mask_process);
DECLARE_FUNC_CONS(bvgl_generate_mask_process2);
DECLARE_FUNC_CONS(bvgl_set_change_type_process);

#endif
